@@ -96,7 +96,7 @@ class EnviarPedido(Enviar):
             )
             for item in self.pedido.itens.all()
         ]
-        items.append(Item(title="Frete", quantity=1, currency_id="BRL", unit_price=self.formatador.formata_decimal(self.pedido.valor_envio, como_float=True)))
+        items.append(Item(title="Frete", quantity=1, currency_id="BRL", unit_price=self.formatador.formata_decimal(self.valor_envio, como_float=True)))
         return items
 
     def obter_situacao_do_pedido(self, status_requisicao):
